*******************************************************************************
****** This do file contructs the Abadie weights used in the main analysis
*******************************************************************************



clear

use Data\Compiled\datasnl-final.dta

gen MA_GI=0 

replace MA_GI=1 if state=="ME" | state=="NY"  | state=="VT" | state=="WA" | state=="MA" 

encode state, gen(stateid)



**** Normalize year to 2007

gen yearold=year

replace year=year-2007


*** drop these states because they don't have complete pre-reform time series of data, which is crirtical for contructing the weights

drop if state=="AK" | state=="DE"  | state=="DC" | state=="MS" | state=="SD" | state=="OK" 



sort state year


*** demean

gen prem_ind_res=.


levelsof stateid, local(stateidlist)




 foreach s of local stateidlist {
 quietly sum prem_per_year_ind if stateid==`s' & yearold<2006
 
 replace prem_ind_res=prem_per_year_ind-r(mean) if stateid==`s'
 
}
***


sort state year

** construct relative changes in costs and premiums 

gen trend=prem_per_year_ind[_n+1]-prem_per_year_ind if state[_n+1]==state

gen trendcost=prov_health_serv_incur_ind_year[_n+1]-prov_health_serv_incur_ind_year if state[_n+1]==state

gen trendrel=(prem_per_year_ind[_n+1]-prem_per_year_ind)/prem_per_year_ind if state[_n+1]==state

gen trendrelcost=(prov_health_serv_incur_ind_year[_n+1]-prov_health_serv_incur_ind_year)/prov_health_serv_incur_ind_year if state[_n+1]==state





tsset stateid yearold



gen lgac=log(prov_health_serv_incur_ind_year)

gen lgprem=log(prem_per_year_ind)


gen mem_mo_ind_rel=.

**** For all States: express enrollment in percentages (mem_mo_ind is number of insured in member months)
**** insurance300post is coverage in the post-reform years measured in the NHIS


levelsof state, local(levels) 

foreach l of local levels {

quietly sum mem_mo_ind if yearold>2007 & yearold<=2010 & state=="`l'"

local ypostma=r(mean)

replace mem_mo_ind_rel=mem_mo_ind/`ypostma'*insurance300post if state=="`l'" 


}
***

**** Adjust Other States if estimate exceeds 120%



by stateid, sort: egen endcov_share=max(mem_mo_ind_rel)

replace mem_mo_ind_rel=mem_mo_ind_rel/endcov_share if endcov_share>1.2


**** Creat changes in coverage


sort state yearold

gen trendcov=mem_mo_ind_rel[_n+1]-mem_mo_ind_rel if state[_n+1]==state


**** 
** lgacadj
****

*** Normalize log claim expenditures to 2004 levels

by state, sort: gen lgac04=lgac if yearold==2004

by state, sort: egen lgac04all=min(lgac04)


by state, sort: gen ac04=prov_health_serv_incur_ind_year if yearold==2004

by state, sort: egen ac04all=min(ac04)


gen lgac_adj=lgac-lgac04all

gen ac_adj=prov_health_serv_incur_ind_year-ac04all



**** Drop outliers

gen outlier=0

replace outlier=1 if yearold==2004 & (trendrelcost> 0.4 | trendrelcost<-0.4)

gen outliercov=0

replace outliercov=1 if yearold==2004 & (trendcov> 0.25 | trendcov<-0.25)

gen outlierprem=0

replace outlierprem=1 if yearold==2004 & (trendrel> 0.4 | trendrel<-0.4)



by state, sort: egen outliermax=max(outlier)

by state, sort: egen outliercovmax=max(outliercov)

by state, sort: egen outlierpremmax=max(outlierprem)



by state, sort: egen minrelcost=min(trendrelcost)

by state, sort: egen maxrelcost=max(trendrelcost)



*** Normalize log premiums to 2004 levels

by state, sort: gen lgprem04=lgprem if yearold==2004

by state, sort: egen lgprem04all=min(lgprem04)

gen lgprem_adj=lgprem-lgprem04all


*** Normalize coverage to 2004 levels


by state, sort: gen cov04=mem_mo_ind_rel if yearold==2004

by state, sort: egen cov04all=min(cov04)

gen cov_adj=mem_mo_ind_rel-cov04all






gen trendrelcostnorm=trendrelcost
replace trendrelcostnorm=-10000 if trendrelcost>0.4 | trendrelcost<-0.4


drop if maxrelcost>0.4 | minrelcost<-0.4



quietly synth lgac_adj trendrelcost(2004)  trendrel(2004) trendcov(2004)  mem_mo_ind(2004 & 2005), trunit(19) trperiod(2006) fig

graph save Data\Compiled\Figures\lgac_all_all.gph, replace

matrix Aallall=e(W_weights)


****  GI


quietly synth lgac_adj trendrelcost(2004)  trendrel(2004) trendcov(2004)  mem_mo_ind(2004 & 2005) MA_GI, trunit(19) trperiod(2006) fig

graph save Data\Compiled\Figures\lgac_all_gi.gph, replace

matrix Agiall=e(W_weights)




clear


svmat Aallall, names(wallall)

svmat Agiall, names(wallgi)

drop wallgi1 

rename wallall1 statenr

sort statenr

save Data\Compiled\abadieweights.dta, replace

clear all





