*******************************************************************************
*** This dofile conducts a robustness check with respect to the inclusion of additional 
*** demographic control variables. The results are presnted in the appendix section of the paper
*** Speicifically, we derive here the point estimates and consider inference (via Bootstrap) in a different dofile
*******************************************************************************



clear all

set more off

use Data\Compiled\datasnl-final.dta


encode state, gen(stateid)

gen statenr=stateid

sort statenr

merge m:1 statenr using Data\Compiled\abadieweights.dta


replace wallall2=1/35 if state=="MA"



replace wallall2=0 if wallall2==.



drop if wallall2==0




gen MA_GI=0 

replace MA_GI=1 if state=="ME" | state=="NY"  | state=="VT" | state=="WA" | state=="MA" 
*replace MA_GI=1 if state=="NJ" | state=="ME" | state=="NY"  | state=="VT" | state=="WA" | state=="MA" 

*** Generaate stateid (for clustering)



**** Normalize year to 2007

gen yearold=year

replace year=year-2007



*** Period Identfiers


gen during=0

replace during=1 if yearold==2006 | yearold==2007



gen after=0

replace after=1 if yearold>2007


**** Interaction Terms

gen MAafter=after*MA

gen MAduring=during*MA


**** Trends


gen MAyear=MA*year


gen after_year=after*year


gen during_year=during*year


gen after_MA_year=after*year*MA


gen during_MA_year=during*year*MA


sort stateid year


gen mem_mo_ind_rel=.

levelsof state, local(levels) 


foreach l of local levels {

quietly sum mem_mo_ind if yearold>2007 & yearold<=2010 & state=="`l'"

local ypostma=r(mean)

replace mem_mo_ind_rel=mem_mo_ind/`ypostma'*insurance300post if state=="`l'" 


}
**

by stateid, sort: egen endcov_share=max(mem_mo_ind_rel)

replace mem_mo_ind_rel=mem_mo_ind_rel/endcov_share if endcov_share>1.2



*** merge controls on

drop _merge

sort yearold state

*** We merge prepared raw data from the American Community Survey (for details about the raw data please contact the authors)

merge yearold state using Data\ACS\dataacs.dta
 
 
keep if _merge==3

drop _merge

label variable MAafter "MA*After"
label variable MAduring "MA*During" 
label variable MA "MA"
label variable after "After"
label variable sh1824 "Share 18-24"
label variable sh2534 "Share 25-34"
label variable sh3544 "Share 35-44"
label variable sh4554 "Share 45-54"
label variable shwomen1864 "Women Share"
label variable shwhite1864 "Share White"
label variable shblack1864 "Share Black"
label variable unemploy1864 "Share Umemployed"
label variable wage1864 "Avg Salary"
 
 
 
 ********** Member Months
 
quietly reg mem_mo_ind_rel MAafter MAduring MA after during if yearold<2011 [aweight=wallall2], cluster(stateid) 

estimates save Data\Compiled\memnorm, replace

 
quietly reg mem_mo_ind_rel MAafter MAduring MA after during sh1824 sh2534 sh3544 sh4554 shwomen1864 shblack1864 shwhite1864 shasian1864 unemploy1864 wage1864 if yearold<2011 [aweight=wallall2], cluster(stateid) 

estimates save Data\Compiled\memall, replace
 
 
*** AC 
 
gen lgac=log(prov_health_serv_incur_ind_year)

quietly reg lgac MAafter MAduring MA after during if yearold<2011 [aweight=wallall2], cluster(stateid) 

estimates save Data\Compiled\acnorm, replace
 
quietly reg lgac MAafter MAduring MA after during sh1824 sh2534 sh3544 sh4554 shwomen1864 shblack1864 shwhite1864 shasian1864 unemploy1864 wage1864 if yearold<2011 [aweight=wallall2], cluster(stateid) 

estimates save Data\Compiled\acall, replace
 


*** Prem

gen lgprem=log(prem_per_year_ind)

quietly reg lgprem MAafter MAduring MA after during if yearold<2011 [aweight=wallall2], cluster(stateid) 

estimates save Data\Compiled\premnorm, replace

 
quietly reg lgprem MAafter MAduring MA after during sh1824 sh2534 sh3544 sh4554 shwomen1864 shblack1864 shwhite1864 shasian1864 unemploy1864 wage1864 if yearold<2011 [aweight=wallall2], cluster(stateid) 

estimates save Data\Compiled\premall, replace
 



clear

estimates use Data\Compiled\memnorm

matrix define para=e(b)

matrix para=[para[1,1..5],0,0,0,0,0,0,0,0,0,0,para[1,6]]'

matrix parall=para

matrix drop para


estimates use Data\Compiled\memall

matrix define para=e(b)

matrix para=[para[1,1..16]]'

matrix parall=parall,para

matrix drop para


estimates use Data\Compiled\premnorm

matrix define para=e(b)

matrix para=[para[1,1..5],0,0,0,0,0,0,0,0,0,0,para[1,6]]'

matrix parall=parall,para

matrix drop para


estimates use Data\Compiled\premall

matrix define para=e(b)

matrix para=[para[1,1..16]]'

matrix parall=parall,para

matrix drop para


estimates use Data\Compiled\acnorm

matrix define para=e(b)

matrix para=[para[1,1..5],0,0,0,0,0,0,0,0,0,0,para[1,6]]'

matrix parall=parall,para

matrix drop para


estimates use Data\Compiled\acall

matrix define para=e(b)

matrix para=[para[1,1..16]]'

matrix parall=parall,para

matrix drop para



svmat parall

save Data\Compiled\pointestrob.dta, replace



eststo clear

clear all

