*******************************************************************************
****** This dofile builds on the placeboweigths and runs the regressions + saves the result for the placebo state
*******************************************************************************

clear


use Data\Compiled\datasnl-final.dta

replace MA=0

replace MA=1 if state=="$state"


encode state, gen(stateid)

gen statenr=stateid

sort statenr

merge m:1 statenr using Data\Compiled\weightsplacebo.dta


replace wallall2=1/35 if MA==1


replace wallall2=0 if wallall2==.



drop if wallall2==0



**** Normalize year to 2007

gen yearold=year

replace year=year-2007



*** Period Identfiers


gen during=0

replace during=1 if yearold==2006 | yearold==2007



gen after=0

replace after=1 if yearold>2007


**** Interaction Terms

gen MAafter=after*MA

gen MAduring=during*MA


**** Trends


gen MAyear=MA*year


gen after_year=after*year


gen during_year=during*year


gen after_MA_year=after*year*MA


gen during_MA_year=during*year*MA


sort stateid year

**** Other States


**** get mean estimates

gen mem_mo_ind_rel=.

levelsof state, local(levels) 


foreach l of local levels {

quietly sum mem_mo_ind if yearold>2007 & yearold<=2010 & state=="`l'"

local ypostma=r(mean)

replace mem_mo_ind_rel=mem_mo_ind/`ypostma'*insurance300post if state=="`l'" 


}
**

by stateid, sort: egen endcov_share=max(mem_mo_ind_rel)

replace mem_mo_ind_rel=mem_mo_ind_rel/endcov_share if endcov_share>1.2



gen lgprem=log(prem_per_year_ind)


gen lgac=log(prov_health_serv_incur_ind_year)


***************************************************************************************************
*** time series
***************************************************************************************************


levelsof yearold, local(yearolds)

foreach year of local yearolds {

quietly sum mem_mo_ind_rel if yearold==`year' & MA==1

local covma=r(mean)

quietly sum mem_mo_ind_rel if yearold==`year' & MA==0 [aweight=wallall2]

local covnoma=r(mean)

local covdiff=`covma'-`covnoma'


matrix diffenr`year'=`covdiff'


*** AC

quietly sum lgac if yearold==`year' & MA==1

local acma=r(mean)

quietly sum lgac if yearold==`year' & MA==0 [aweight=wallall2]

local acnoma=r(mean)

local acdiff=`acma'-`acnoma'

matrix diffac`year'=`acdiff'


*** Prem

quietly sum lgprem if yearold==`year' & MA==1

local premma=r(mean)

quietly sum lgprem if yearold==`year' & MA==0 [aweight=wallall2]

local premnoma=r(mean)

local premdiff=`premma'-`premnoma'

matrix diffprem`year'=`premdiff'


} 
*****

local statecounterloc =$statecounter


matrix enrtimeseries`statecounterloc'=diffenr2004, diffenr2005, diffenr2006, diffenr2007, diffenr2008, diffenr2009, diffenr2010

svmat enrtimeseries`statecounterloc'

save Data\Compiled\enrtimeseries`statecounterloc'.dta, replace

clear

matrix drop diffenr2004 diffenr2005 diffenr2006 diffenr2007 diffenr2008 diffenr2009 diffenr2010

matrix actimeseries`statecounterloc'=diffac2004, diffac2005, diffac2006, diffac2007, diffac2008, diffac2009, diffac2010

svmat actimeseries`statecounterloc'

save Data\Compiled\actimeseries`statecounterloc'.dta, replace

clear

matrix drop diffac2004 diffac2005 diffac2006 diffac2007 diffac2008 diffac2009 diffac2010

matrix premtimeseries`statecounterloc'=diffprem2004, diffprem2005, diffprem2006, diffprem2007, diffprem2008, diffprem2009, diffprem2010

svmat premtimeseries`statecounterloc'

save Data\Compiled\premtimeseries`statecounterloc'.dta, replace

clear

matrix drop diffprem2004 diffprem2005 diffprem2006 diffprem2007 diffprem2008 diffprem2009 diffprem2010


clear




